@@ -154,6 +154,7 @@ var app = new Vue({
             const url = `/datapackage-creator/show-datapackage-resource/${this.resources[0].id}`
             axios.get(url).then(res => {
                 this.package_id = res.data.resource.package_id
+                console.log(this.package_id)
                 this.resources = []
                 this.resources.push(JSON.parse(res.data.datapackage_resource.data))
             })
@@ -390,6 +391,13 @@ var app = new Vue({
             }
             return readonly
         },
+        isRequired(field_name) {
+            let required = false
+            if(this.settings != null && this.settings.resource && this.settings.resource.required) {
+                required = this.settings.resource.required.includes(field_name)
+            }
+            return required
+        },
         filterMetadataTypeOptions(field) {
             return this.metadataTypeOptions.filter(function(value, index, arr){
                 if(value.value == 'pattern') {
